# frozen_string_literal: true
require 'test_helper'

require 'eaternet'
require 'eaternet/lives_1_0'

class AustinAdapterTest < Minitest::Test
  def austin_agency
    Eaternet::Austin.new
  end

  #
  # Businesses
  #

  def test_businesses_returns_an_enumerator_of_business
    VCR.use_cassette(AUSTIN_CASSETTE) do
      assert enumerable_of? Eaternet::Lives_1_0::Business, austin_agency.businesses
    end
  end

  def test_businesses_returns_correct_attributes
    VCR.use_cassette(AUSTIN_CASSETTE) do
      b = austin_agency.businesses.find { |biz| biz.business_id == '2801033' }
      assert_equal '15th Street Cafe', b.name
      assert_equal '303 W 15TH ST', b.address
      assert_equal 'AUSTIN', b.city
      assert_equal '78701', b.postal_code
      assert_equal 'TX', b.state
      assert_in_delta  30.277553492000038, b.latitude
      assert_in_delta(-97.74209889799994, b.longitude)
    end
  end


  #
  # Inspections
  #

  def test_inspections_returns_an_enumerable_of_inspection
    VCR.use_cassette(AUSTIN_CASSETTE) do
      assert enumerable_of? Eaternet::Lives_1_0::Inspection, austin_agency.inspections
    end
  end

  def test_inspections_returns_correct_attributes
    VCR.use_cassette(AUSTIN_CASSETTE) do
      i = austin_agency.inspections.find { |x|
        x.business_id == '10811324' && x.date.iso8601 == '2014-06-03'
      }
      assert_equal 100, i.score
    end
  end

  #
  # Violations
  #

  def test_violations_raises_an_unsupported_error
    VCR.use_cassette(AUSTIN_CASSETTE) do
      assert_raises(Eaternet::UnsupportedError) { austin_agency.violations }
    end
  end

  def test_violations_raises_an_error_with_a_message
    VCR.use_cassette(AUSTIN_CASSETTE) do
      begin
        austin_agency.violations
      rescue => e
        assert_match(/doesn't/, e.to_s)
      end
    end
  end


  # #
  # # metadata
  # #
  #
  def test_implements_feed_info
    VCR.use_cassette(AUSTIN_CASSETTE) do
      assert_instance_of Eaternet::Lives_1_0::FeedInfo, austin_agency.feed_info
    end
  end

  def test_legends_raises_an_unsupported_error
    VCR.use_cassette(AUSTIN_CASSETTE) do
      assert_raises(Eaternet::UnsupportedError) { austin_agency.legends }
    end
  end
end
