# frozen_string_literal: true
require 'test_helper'
require 'eaternet'

class Lives2Test < Minitest::Test
  # Instantiating as an app developer would:
  @@l2 = Eaternet::Lives2.new(
    feed_url:          'https://extxfer.sfdph.org/food/SFBusinesses.zip',
    municipality_name: 'San Francisco',
    municipality_url:  'http://www.sfgov.org',
    contact_email:     'richard.lee@sfdph.org'
  )

  #
  # Businesses
  #

  def test_businesses_returns_an_enumerator_of_business
    VCR.use_cassette(L2_CASSETTE) do
      assert enumerable_of? Eaternet::Lives_1_0::Business, @@l2.businesses
    end
  end

  def test_businesses_returns_lives_attributes
    VCR.use_cassette(L2_CASSETTE) do
      b = @@l2.businesses.first
      assert_equal '10',               b.business_id
      assert_equal 'TIRAMISU KITCHEN', b.name
      assert_equal '033 BELDEN PL',    b.address
      assert_equal 'San Francisco',    b.city
      assert_equal '94104',            b.postal_code
      assert_equal 'CA',               b.state
      assert_equal 37.791116,          b.latitude
      assert_equal -122.403816,        b.longitude
      assert_equal '+14154217044',     b.phone_number
    end
  end

  #
  # Inspections
  #

  def test_inspections_returns_an_enumerable_of_inspection
    VCR.use_cassette(L2_CASSETTE) do
      assert enumerable_of? Eaternet::Lives_1_0::Inspection, @@l2.inspections
    end
  end

  def test_inspections_returns_lives_attributes
    VCR.use_cassette(L2_CASSETTE) do
      chosen_inspection = @@l2.inspections
                              .find { |i| i.business_id == '19' && i.date == Date.new(2016, 5, 13) }
      raise "Couldn't find the chosen inspection" if chosen_inspection.nil?
      assert_equal 94, chosen_inspection.score
    end
  end

  #
  # Violations
  #

  def test_violations_returns_an_enumerable_of_violation
    VCR.use_cassette(L2_CASSETTE) do
      assert enumerable_of? Eaternet::Lives_1_0::Violation, @@l2.violations
    end
  end

  # TODO: Fix this test
  # def test_violations_returns_lives_attributes
  #   VCR.use_cassette(L2_CASSETTE) do
  #     v = @@l2.violations.first
  #     assert_equal '10', v.business_id
  #     assert_equal Date.new(2014, 7, 29), v.date
  #     assert_equal nil, v.code
  #     assert_match /^Insufficient hot water or running water$/, v.description
  #   end
  # end

  #
  # metadata
  #

  def test_implements_feed_info
    assert_instance_of Eaternet::Lives_1_0::FeedInfo, @@l2.feed_info
  end

  #
  # Other
  #

  # def test_handles_file_encoding
  #   refute_nil @@l2.businesses.to_a
  # end
end
