require 'test_helper'
require 'eaternet/agencies/snhd_prototype'


class SnhdPrototypeAdapterTest < Minitest::Test
  @@snhd_prototype = Eaternet::Agencies::SnhdPrototype.new

  #
  # Namespace and access
  #

  def test_global_namespace_not_polluted
    assert_raises(NameError) { SnhdPrototype }
  end

  #
  # #businesses
  #

  def test_businesses_returns_an_enumerator
    VCR.use_cassette(SNHD_CASSETTE) do
      assert_kind_of Enumerable, @@snhd_prototype.businesses
    end
  end

  def test_businesses_returns_business_data_objects
    VCR.use_cassette(SNHD_CASSETTE) do
      assert_kind_of Eaternet::Prototype::BusinessData, @@snhd_prototype.businesses.first
    end
  end

  def test_businesses_returns_correct_data
    VCR.use_cassette(SNHD_CASSETTE) do
      b = @@snhd_prototype.businesses.first
      assert_equal 'PR0000002', b.orig_key
      assert_equal "McDonald's #3549 D HOTEL", b.name
      assert_equal '301 Fremont St', b.address
      assert_equal 'Las Vegas', b.city
      assert_equal '89101-5600', b.zipcode
    end
  end

  #
  # #inspections
  #

  def test_inspections_returns_an_enumerable
    VCR.use_cassette(SNHD_CASSETTE) do
      assert_kind_of Enumerable, @@snhd_prototype.inspections
    end
  end

  def test_inspections_returns_inspection_data_objects
    VCR.use_cassette(SNHD_CASSETTE) do
      assert_kind_of(
        Eaternet::Prototype::InspectionData,
        @@snhd_prototype.inspections.first
      )
    end
  end

  # def test_inspections_returns_correct_data
  #   VCR.use_cassette(SNHD_CASSETTE) do
  #     i = @@snhd_prototype.inspections.first(6).last
  #     assert_equal 'DA0001095', i.orig_key
  #     assert_equal 'PR0000411', i.business_orig_key
  #     assert_equal 'A', i.score
  #     assert_equal '1994-04-15 00:00:00', i.date
  #   end
  # end

  #
  # #violations
  #

  def test_violations_returns_an_enumerable
    VCR.use_cassette(SNHD_CASSETTE) do
      assert_kind_of Enumerable, @@snhd_prototype.violations
    end
  end

  def test_violations_returns_violation_data_objects
    VCR.use_cassette(SNHD_CASSETTE) do
      assert_kind_of Eaternet::Prototype::ViolationData, @@snhd_prototype.violations.first
    end
  end

  def test_violations_returns_correct_data
    VCR.use_cassette(SNHD_CASSETTE) do
      v = @@snhd_prototype.violations.first
      assert_equal 'n/a',       v.orig_key
      assert_equal 'DA0001096', v.inspection_id
      assert_equal '8',         v.violation_kind_id
    end
  end

  #
  # #violation_kinds
  #

  def test_violation_kinds_returns_an_enumerable
    VCR.use_cassette(SNHD_CASSETTE) do
      assert_kind_of Enumerable, @@snhd_prototype.violation_kinds
    end
  end

  def test_violation_kinds_returns_violation_kind_data_objects
    VCR.use_cassette(SNHD_CASSETTE) do
      assert_kind_of(
        Eaternet::Prototype::ViolationKindData,
        @@snhd_prototype.violation_kinds.first
      )
    end
  end

  def test_violation_kinds_returns_correct_data
    VCR.use_cassette(SNHD_CASSETTE) do
      v = @@snhd_prototype.violation_kinds.first
      assert_equal '1', v.orig_key
      assert_equal '1', v.code
      assert_equal '6', v.demerits
      assert_equal(
        'Food not obtained from approved sources and/or improperly identified.',
        v.description
      )
    end
  end
end
