require 'test_helper'

require 'eaternet/lives_1_0'

class BusinessTest < Minitest::Test
  #
  # Business#latitude and Business#longitude
  #

  PORTLAND_OR_US = { lat: 45.5236111, lon: -122.675 }

  def test_creates_business_without_lat_and_lon
    business = Eaternet::Lives_1_0::Business.new do |i|
      i.business_id = '789123hjd'
      i.name = 'Starbucks'
      i.address = '123 Happy Lane'
    end
    refute_nil business
  end

  def test_rejects_lat_and_lon_which_are_not_numbers
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::Business.new do |i|
        i.business_id = '789123hjd'
        i.name = 'Starbucks'
        i.address = '123 Happy Lane'
        i.latitude = 'north'
        i.longitude = '45.2'
      end
    }
  end

  def test_creates_business_with_lat_and_lon
    business = Eaternet::Lives_1_0::Business.new do |i|
      i.business_id = '789123hjd'
      i.name = 'Starbucks'
      i.address = '123 Happy Lane'
      i.latitude = PORTLAND_OR_US[:lat]
      i.longitude = PORTLAND_OR_US[:lon]
    end
    refute_nil business
  end

  def test_returns_float_lat_and_long
    business = Eaternet::Lives_1_0::Business.new do |i|
      i.business_id = '789123hjd'
      i.name = 'Starbucks'
      i.address = '123 Happy Lane'
      i.latitude = PORTLAND_OR_US[:lat].to_s
      i.longitude = PORTLAND_OR_US[:lon].to_s
    end

    assert_instance_of Float, business.latitude
    assert_instance_of Float, business.longitude
  end

  def test_rejects_invalid_latitude
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::Business.new do |i|
        i.business_id = '789123hjd'
        i.name = 'Starbucks'
        i.address = '123 Happy Lane'
        i.latitude = 91
        i.longitude = PORTLAND_OR_US[:lon]
      end
    }
  end

  def test_rejects_invalid_longitude
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::Business.new do |i|
        i.business_id = '789123hjd'
        i.name = 'Starbucks'
        i.address = '123 Happy Lane'
        i.latitude = PORTLAND_OR_US[:lat]
        i.longitude = -181
      end
    }
  end

  #
  # Business#name
  #

  def test_rejects_blank_name
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::Business.new do |i|
        i.business_id = '789123hjd'
        i.name = ''
        i.address = '123 Happy Lane'
      end
    }
  end
end
