require 'test_helper'

require 'eaternet/lives_1_0'

class FeedInfoTest < Minitest::Test
  def set_required_attrs(feed_info)
    feed_info.feed_date = Date.new(2015, 1, 1)
    feed_info.feed_version = '1.0'
    feed_info.municipality_name = 'Dallas'
  end

  def setup
    @dallas = Eaternet::Lives_1_0::FeedInfo.new { |i| set_required_attrs(i) }
  end


  #
  # FeedInfo#date
  #

  def test_rejects_when_missing_feed_date
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::FeedInfo.new do |i|
        i.feed_version = '1.0'
        i.municipality_name = 'NYC'
      end
    }
  end

  def test_rejects_incorrect_feed_date_type
    @dallas.feed_date = '2015-01-01'
    refute @dallas.valid?
  end

  def test_rejects_nil_feed_date
    @dallas.feed_date = nil
    refute @dallas.valid?
  end

  #
  # FeedInfo#municipality_url
  #

  def test_with_url
    @dallas.municipality_url = 'http://www.nyc.gov/html/doh/html/services/restaurant-inspection.shtml'
    assert @dallas.valid?
  end

  def test_rejects_malformed_url
    @dallas.municipality_url = 'www.nyc.gov'
    refute @dallas.valid?
  end

  #
  # FeedInfo#contact_email
  #

  def test_with_email
    @dallas.contact_email = 'Pressoffice@health.nyc.gov'
    assert @dallas.valid?
  end

  def test_rejects_malformed_email
    @dallas.contact_email = 'myaddress.com'
    refute @dallas.valid?
  end

  def test_accepts_email_with_plus_in_name
    @dallas.contact_email = 'Pressoffice+temp@health.nyc.gov'
    assert @dallas.valid?
  end
end
