require 'test_helper'

require 'eaternet/lives_1_0'

class InspectionTest < Minitest::Test
  #
  # Inspection#type
  #

  def test_with_a_valid_type
    inspection = Eaternet::Lives_1_0::Inspection.new do |i|
      i.business_id = 'abcdef1'
      i.score = 98
      i.date = Date.new(2012, 2, 3)
      i.type = 'initial'
    end
    refute_nil inspection
  end

  def test_rejects_unspecified_types
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::Inspection.new do |i|
        i.business_id = 'abcdef1'
        i.score = 98
        i.date = Date.new(2012, 2, 3)
        i.type = 'auto inspection'
      end
    }
  end

  def test_without_a_type
    inspection = Eaternet::Lives_1_0::Inspection.new do |i|
      i.business_id = 'abcdef1'
      i.score = 98
      i.date = Date.new(2012, 2, 3)
    end
    refute_nil inspection
  end


  #
  # Inspection#score
  #

  def test_accepts_a_blank_score
    inspection = Eaternet::Lives_1_0::Inspection.new do |i|
      i.score = ''
      i.business_id = 'abcdef1'
      i.date = Date.new(2012, 2, 3)
    end
    refute_nil inspection
  end

  def test_accepts_a_numeric_score
    inspection = Eaternet::Lives_1_0::Inspection.new do |i|
      i.score = 96
      i.business_id = 'abcdef1'
      i.date = Date.new(2012, 2, 3)
    end
    refute_nil inspection
  end

  def test_rejects_a_score_out_of_bounds
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::Inspection.new do |i|
        i.score = 101
        i.business_id = 'abcdef1'
        i.date = Date.new(2012, 2, 3)
      end
    }
  end

  def test_rejects_a_non_numeric_score
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::Inspection.new do |i|
        i.score = '100'
        i.business_id = 'abcdef1'
        i.date = Date.new(2012, 2, 3)
      end
    }
    assert_raises(ArgumentError) {
      Eaternet::Lives_1_0::Inspection.new do |i|
        i.score = 'A'
        i.business_id = 'abcdef1'
        i.date = Date.new(2012, 2, 3)
      end
    }
  end

  def test_with_no_score_sets_it_to_blank
    inspection = Eaternet::Lives_1_0::Inspection.new do |i|
      i.business_id = 'abcdef1'
      i.date = Date.new(2012, 2, 3)
    end
    assert_equal('', inspection.score)
  end
end
