# frozen_string_literal: true
require 'tempfile'
require 'test_helper'
require 'timecop'

require 'eaternet/util'

class UtilTest < Minitest::Test
  def setup
    @file_contents = 'This is the file'
    @url = "http://downloadtest.com/file-#{rand(1_000_000)}.txt"
    @file = Tempfile.new('temp')
    stub_request(:get, @url).to_return(body: @file_contents)
  end

  def download
    Eaternet::Util.download(source: @url, dest: @file)
  end

  def download_and_cache
    Eaternet::Util.download_and_cache(source: @url, dest: @file)
  end

  def test_downloads_a_file
    download
    assert_equal @file_contents, `cat #{@file.path}`.strip
    assert_requested :get, @url, times: 1
  end

  def test_downloads_a_file_with_cache_option
    download_and_cache
    assert_equal @file_contents, `cat #{@file.path}`.strip
    assert_requested :get, @url, times: 1
  end

  def test_uses_a_file_cache
    3.times { download_and_cache }
    assert_requested :get, @url, times: 1
  end

  def test_expires_a_cache_file
    thirteen_hours = 13 * 60 * 60
    download_and_cache
    Timecop.freeze(Time.now + thirteen_hours) { download_and_cache }
    assert_requested :get, @url, times: 2
  end
end
