require 'date'
require 'eaternet/validated_object'

# @example Writing a self-validating object
#   class Dog < Eaternet::ValidatedObject
#     attr_accessor :name, :birthday
#
#     validates :name, presence: true
#     validates :birthday, type: Date, allow_nil: true
#   end
#
# @example Instantiating and automatically validating
#   # The dog1 instance is validated at the end of instantiation.
#   # Here, it succeeds without exception.
#   dog1 = Dog.new do |d|
#     d.name = 'Spot'
#   end
#
#   # We can also explicitly test for validity
#   dog1.valid?  # => true
#
#   dog1.birthday = Date.new(2015, 1, 23)
#   dog1.valid?  # => true
#
# @example Making an instance invalid
#   dog1.birthday = '2015-01-23'
#   dog1.valid?  # => false
#   dog1.check_validations!  # => ArgumentError: birthday is not of class Date

class Dog < Eaternet::ValidatedObject
  attr_accessor :name, :birthday

  validates :name, presence: true
  validates :birthday, type: Date, allow_nil: true
end

dog1 = Dog.new do |d|
  d.name = 'Spot'
end
puts "dog1.valid? #{dog1.valid?}"

dog1.birthday = '2015-01-23'
dog1.check_validations!
